package com.hdp.piplus.lts;

import com.google.common.base.Splitter;
import com.hdp.piplus.lts.jobclient.JobClientFactory;
import com.hdp.piplus.lts.jobtracker.JobTrackerLauncher;
import com.hdp.piplus.lts.tasktracker.TaskTrackerLauncher;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.ApplicationContext;

@SpringBootApplication
@EnableConfigurationProperties
public class LtsApp implements CommandLineRunner {
    private static final Logger logger = LoggerFactory.getLogger(LtsApp.class);

    @Autowired
    private ApplicationContext context;

    @Value("${piplus.lts.services}")
    private String ltsServices;

    @Autowired
    private JobTrackerLauncher jobTrackerLauncher;

    @Autowired
    private TaskTrackerLauncher taskTrackerLauncher;

    public static void main(String[] args) throws Exception {
        SpringApplication.run(LtsApp.class, args);
    }

    @Override
    public void run(String... args) throws Exception {
        for (String service: Splitter.on(",").split(ltsServices)) {
            if (service.equalsIgnoreCase("jobtracker")) {
                logger.info("=====启动jobtracker=====");
                jobTrackerLauncher.launch();
            } else if (service.equalsIgnoreCase("tasktracker")) {
                logger.info("=====启动tasktracker=====");
                taskTrackerLauncher.launch();
            } else if (service.equalsIgnoreCase("jobClient")) {
                logger.info("=====启动jobClient=====");
                JobClientFactory.init(context);
                JobClientFactory.getJobClient();
            } else {
                logger.warn("未知服务：" + service);
            }
        }
    }
}
