package com.hdp.piplus.lts.jobclient;

import com.google.common.base.Splitter;
import com.google.common.collect.Lists;
import com.lts.core.commons.utils.StringUtils;
import com.lts.core.listener.MasterChangeListener;
import com.lts.jobclient.JobClient;
import com.lts.spring.JobClientFactoryBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.core.env.Environment;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Properties;

@Component
@Lazy
public class BootJobClientFactoryBean extends JobClientFactoryBean {
    @Autowired
    private Environment env;

    /**
     * 使用Spring Boot配置机制配置JobClientFactoryBean
     * @see JobClientFactoryBean
     * @throws Exception
     */
    @Override
    public void afterPropertiesSet() throws Exception {
        setClusterName(env.getProperty("clusterName"));
        setRegistryAddress(env.getProperty("registryAddress"));
        setNodeGroup(env.getProperty("jobclient.nodeGroup"));
        String values = env.getProperty("jobclient.masterChangeListeners");
        if (StringUtils.isNotEmpty(values)) {
            List<MasterChangeListener> listeners = Lists.newArrayList();
            for (String clsName: Splitter.on(",").split(values)) {
                listeners.add((MasterChangeListener) Class.forName(clsName).newInstance());
            }
            setMasterChangeListeners(listeners.toArray(new MasterChangeListener[listeners.size()]));
        }

        Properties configs = new Properties();
        configs.setProperty("job.fail.store", env.getProperty("configs.job.fail.store"));
        setConfigs(configs);

        super.afterPropertiesSet();
    }
}
