package com.hdp.piplus.lts.jobtracker;

import com.lts.core.commons.utils.StringUtils;
import com.lts.jobtracker.JobTracker;
import com.lts.jobtracker.support.policy.OldDataDeletePolicy;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.env.Environment;
import org.springframework.stereotype.Component;

@Component
public class JobTrackerLauncher {
    @Autowired
    private Environment env;

    public void launch() {
        JobTracker jobTracker = new JobTracker();
        jobTracker.setRegistryAddress(env.getProperty("registryAddress"));
        jobTracker.setClusterName(env.getProperty("clusterName"));
        jobTracker.setListenPort(Integer.parseInt(env.getProperty("jobtracker.listenPort")));
        String value = env.getProperty("jobtracker.bindIp");
        if (StringUtils.isNotEmpty(value)) {
            jobTracker.setBindIp(value);
        }
        // 删除feedbackQueue中超过30天的数据
        jobTracker.setOldDataHandler(new OldDataDeletePolicy());

        // 不能枚举，悲剧
        jobTracker.addConfig("job.logger", env.getProperty("configs.job.logger"));
        jobTracker.addConfig("zk.client", env.getProperty("configs.zk.client"));
        jobTracker.addConfig("job.queue", env.getProperty("configs.job.queue"));

        jobTracker.addConfig("jdbc.url", env.getProperty("configs.jdbc.url"));
        jobTracker.addConfig("jdbc.username", env.getProperty("configs.jdbc.username"));
        jobTracker.addConfig("jdbc.password", env.getProperty("configs.jdbc.password"));

        jobTracker.addConfig("mongo.addresses", env.getProperty("configs.mongo.addresses"));
        jobTracker.addConfig("mongo.database", env.getProperty("configs.mongo.database"));
        jobTracker.addConfig("mongo.username", env.getProperty("configs.mongo.username"));
        jobTracker.addConfig("mongo.password", env.getProperty("configs.mongo.password"));

        jobTracker.start();

        Runtime.getRuntime().addShutdownHook(new Thread(jobTracker::stop));
    }
}
